# Generated by Django 3.1.6 on 2021-02-15 04:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("securepasswords", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="passwordprofile",
            name="force_change",
            field=models.BooleanField(default=False, verbose_name="force change"),
        ),
    ]
